<?php

namespace FiloBlu\GuestWishlist\Helper;

use Magento\Framework\Stdlib\Cookie\CookieMetadataFactory;
use Magento\Framework\Stdlib\CookieManagerInterface;
use Magento\Framework\Session\SessionManagerInterface;

class Data extends \Magento\Framework\App\Helper\AbstractHelper {

    /**
     * Name of Cookie that holds private content version
     */
    CONST COOKIE_NAME = 'guest_wishlist';

    /**
     * @var \Magento\Framework\Stdlib\CookieManagerInterface
     */
    protected $cookieManager;

    /**
     * @var \Magento\Framework\Stdlib\Cookie\CookieMetadataFactory
     */
    protected $cookieMetadataFactory;


    /**
     * @var \Magento\Framework\Session\SessionManagerInterface
     */
    protected $sessionManager;
    
    protected $scopeConfig;

    public function __construct(\Magento\Framework\App\Helper\Context $context, CookieManagerInterface $cookieManager, CookieMetadataFactory $cookieMetadataFactory, SessionManagerInterface $sessionManager
    ) {
        $this->cookieManager = $cookieManager;
        $this->cookieMetadataFactory = $cookieMetadataFactory;
        $this->sessionManager = $sessionManager;
        $this->scopeConfig = $context->getScopeConfig();
    }
    
    public function getConfig($config_path, $section = 'filoblu_guestwishlist_section') {
        return $this->scopeConfig->getValue(
                        $section . '/' . $config_path, \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }


    /**
     * Get data from cookie set in remote address
     *
     * @return value
     */
    public function getCookie($name = null) {
        if (!$name) {
            $name = self::COOKIE_NAME;
        }
        return $this->cookieManager->getCookie($name);
    }

    /**
     * Set data to cookie in remote address
     *
     * @param [string] $value    [value of cookie]
     *
     * @return void
     */
    public function setCookie($value) {
        $metadata = $this->cookieMetadataFactory
                ->createPublicCookieMetadata()
                ->setDuration($this->getConfig("general/cookie_lifetime"))
                ->setPath($this->sessionManager->getCookiePath())
                ->setDomain($this->sessionManager->getCookieDomain());

        $this->cookieManager->setPublicCookie(self::COOKIE_NAME, $value, $metadata);
    }

    /**
     * delete cookie remote address
     *
     * @return void
     */
    public function delete($name) {
        $this->cookieManager->deleteCookie(
                $name, $this->cookieMetadataFactory
                        ->createCookieMetadata()
                        ->setPath($this->sessionManager->getCookiePath())
                        ->setDomain($this->sessionManager->getCookieDomain())
        );
    }

    /**
     * @return var
     */
    public function getCookielifetime() {
        return $this->getConfig("general/cookie_lifetime");
    }

}
