<?php

namespace FiloBlu\GuestWishlist\Setup;

use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

/**
 * Upgrade the Catalog module DB scheme
 */
class UpgradeSchema implements UpgradeSchemaInterface {

    /**
     * {@inheritdoc}
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context) {
        $setup->startSetup();

        if (version_compare($context->getVersion(), '1.0.0', '<')) {
            # Edit db for consistency of data
            $connection = $setup->getConnection();

            $connection->dropForeignKey($setup->getTable("wishlist"), 'WISHLIST_CUSTOMER_ID_CUSTOMER_ENTITY_ENTITY_ID');

            if ($connection->tableColumnExists('wishlist', 'customer_id')) {
                $definition = [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    'nullable' => true,
                    'comment' => 'Customer ID',
                    'unsigned' => true
                ];
                $connection->modifyColumn(
                        $setup->getTable('wishlist'), 'customer_id', $definition
                );
            }


            $tableName = $setup->getTable('wishlist');
            $columnName = 'cookie';

            if ($connection->tableColumnExists($tableName, $columnName) === false) {
                $connection->addColumn($tableName, $columnName, array(
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'default' => '',
                    'comment' => 'Cookie reference'
                ));
            }
        }

        $setup->endSetup();
    }

}
